@@ -11,7 +11,7 @@ log = logging.getLogger(__name__)
 
 __author__ = 'Erik-Jan van Baaren'
 __all__ = ['ESClient']
-__version__ = (0, 4, 0)
+__version__ = (0, 5, 0)
 
 
 def get_version():
@@ -40,9 +40,12 @@ class ESClient:
     def __init__(self, es_url='http://localhost:9200', request_timeout=10):
         self.es_url = es_url
         self.request_timeout = request_timeout
+        self.bulk_data = ''
 
         if self.es_url.endswith('/'):
             self.es_url = self.es_url[:-1]
+
+        # For those that forget the http part, lets just add it
         if not self.es_url.startswith('http://'):
             self.es_url = "http://" + self.es_url
     #
@@ -464,5 +467,33 @@ class ESClient:
         self.send_request('PUT', path=path, body=mapping)
         return self._parse_json_response(self.last_response.text)
 
+    def _bulk_make_param(self, index, doctype, docid, op_type):
+        """Return the bulk format data."""
+        return json.dumps({op_type: {'_index': index, '_type': doctype, '_id': docid}}) + '\n'
+
+    def bulk_index(self, index, doctype, body, docid, op_type='index'):
+        """Bulk index the supplied document."""
+        data = self._bulk_make_param(index, doctype, docid, op_type) + json.dumps(body) + '\n'
+        self.bulk_data += data
+
+    def bulk_delete(self, index, doctype, docid):
+        """Bulk delete document from index."""
+        data = self._bulk_make_param(index, doctype, docid, 'delete')
+        self.bulk_data += data
+
+    def bulk_push(self):
+        """Make a raw HTTP bulk request to ElasticSearch.
+        Returns true if the index was deleted and false otherwise.
+
+        """
+        kwargs = { 'timeout': self.request_timeout }
+        url = self.es_url + '/_bulk'
+        kwargs['data'] = self.bulk_data
+        rescode = requests.request('post', url, **kwargs).status_code
+        self.bulk_data = ''
+        if 200 <= rescode < 300:
+            return True
+        return False
+
 if __name__ == '__main__':
     print "This is a library, it is not intended to be started by itself."
